@@ -60,7 +60,7 @@ class Patch(pdpy.PdPy):
 
   First, we need to do our import::
 
-    >>> import pdpy
+    >>> import pdpy_lib as pdpy
 
   Now, make a patch with a ``name`` and set it to root, non-callback.
 
